aurora/build_scripts
renner a76fa2e80c
refactor: faster kernel installation with a shim (#2926)
This is taken from [1]. We were for no good reason regenerating the initramfs
here. We can also install the kmods with the kernel in one step so I
don't see why we shouldn't just do that. It reduces the amount of time
needed to run this script (on my machine) from 49s to 28s.

I'm not sure if this is an oversight in rpm-ostree, we could technically
use the initramfs that is built during this stage, however, we lose
quite a bit of control, which we definitively want to have.

Also it should generally be noticable when the v4l2 and xone kmods fail
to install. There also haven't been problem regarding that in quite a
while.

[1] 5441c76f1f
2026-09-27 05:34:12 +00:00
..
base refactor: faster kernel installation with a shim (#2926) 2026-09-27 05:34:12 +00:00
dx chore: cleanup systemd services, move to presets (#2892) 2026-09-19 19:44:08 +00:00
shared chore: cleanup systemd services, move to presets (#2892) 2026-09-19 19:44:08 +00:00